@@ -6,7 +6,7 @@ use warnings;
 
 # ABSTRACT: Sugar for DBIx::Class
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 1;
 
@@ -27,16 +27,16 @@ DBIx::Class::Smooth - Sugar for DBIx::Class
 <p>
 <img src="https://img.shields.io/badge/perl-5.20+-blue.svg" alt="Requires Perl 5.20+" />
 <a href="https://travis-ci.org/Csson/p5-DBIx-Class-Smooth"><img src="https://api.travis-ci.org/Csson/p5-DBIx-Class-Smooth.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/release/CSSON/DBIx-Class-Smooth-0.0103"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/DBIx-Class-Smooth/0.0103" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=DBIx-Class-Smooth%200.0103"><img src="http://badgedepot.code301.com/badge/cpantesters/DBIx-Class-Smooth/0.0103" alt="CPAN Testers result" /></a>
-<img src="https://img.shields.io/badge/coverage-58.5%-red.svg" alt="coverage 58.5%" />
+<a href="http://cpants.cpanauthors.org/release/CSSON/DBIx-Class-Smooth-0.0104"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/DBIx-Class-Smooth/0.0104" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=DBIx-Class-Smooth%200.0104"><img src="http://badgedepot.code301.com/badge/cpantesters/DBIx-Class-Smooth/0.0104" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-65.2%-red.svg" alt="coverage 65.2%" />
 </p>
 
 =end html
 
 =head1 VERSION
 
-Version 0.0103, released 2020-05-31.
+Version 0.0104, released 2020-08-30.
 
 =head1 SYNOPSIS
 
@@ -112,7 +112,7 @@ Version 0.0103, released 2020-05-31.
     #* In the Book resultset
     package Your::Schema::ResultSet::Book;
 
-    use Turf::Schema::ResultSet -components => [qw/.../];
+    use Your::Schema::ResultSet -components => [qw/.../];
     use DBIx::Class::Smooth::Q;
 
     sub get_books_by_year($self, $year) {
@@ -126,15 +126,21 @@ Version 0.0103, released 2020-05-31.
     #* Elsewhere, using the Book resultset
     my $books = $schema->Book->get_books_by_year(2018);
 
-=head1 DESCRIPTION
-
-DBIx::Class::Smooth is a sugar layer for L<DBIx::Class>, partially built on top of L<DBIx::Class::Candy> and L<DBIx::Class::Helpers>.
-
 =head1 STATUS
 
 This is experimental, and an early release at that. I'm using this in a couple of non-critical personal projects, so it hasn't seen heavy use. It would not be surprising if there are bad bugs. Also, it's only been tested on MySQL/MariaDB.
 
-More documentation to follow.
+Documentation is expected to improve with time.
+
+=head1 DESCRIPTION
+
+DBIx::Class::Smooth is a sugar layer for L<DBIx::Class>, partially built on top of L<DBIx::Class::Candy> and L<DBIx::Class::Helpers>.
+
+=head1 MORE DOCUMENTATION
+
+for :list
+* L<DBIx::Class::Smooth::Schema>
+* L<DBIx::Class::Smooth::Fields>
 
 =head1 SOURCE
 
